# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#filter emptyLines

# LOCALIZATION NOTE: The 'en-US' strings in the URLs will be replaced with

# your locale code, and link to your translated pages as soon as they're 

# live.


# LOCALIZATION NOTE: Some of these URLs are currently 404s, but should be coming


# online shortly.



# LOCALIZATION NOTE (bookmarks_title):



# title for the folder that will contains the default bookmarks



#define bookmarks_title Móvel



# LOCALIZATION NOTE (bookmarks_aboutBrowser):



# link title for about:fennec



#define bookmarks_aboutBrowser Firefox: Sobre o seu navegador



# LOCALIZATION NOTE (bookmarks_addons):



# link title for https://addons.mozilla.org/en-US/mobile



#define bookmarks_addons Firefox: Personalize com extras



# LOCALIZATION NOTE (bookmarks_support):



# link title for https://support.mozilla.org/



#define bookmarks_support Firefox: Apoio



# LOCALIZATION NOTE (bookmarks_marketplace):



# link title for https://marketplace.firefox.com



#define bookmarks_marketplace Marketplace do Firefox



#unfilter emptyLines
