#filter emptyLines

#define MOZ_LANGPACK_CREATOR SeaMonkey BR

#define MOZ_LANGPACK_HOMEPAGE http://l10n.mozilla.org/pt-BR/seamonkeybr

# If non-English locales wish to credit multiple contributors, uncomment this
# variable definition and use the format specified.
#define MOZ_LANGPACK_CONTRIBUTORS <em:contributor>Caio Tiago Oliveira</em:contributor> <em:contributor>Carlos Une</em:contributor>

#unfilter emptyLines
